<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ" sourcelanguage="en">
<context>
    <name>Preferences</name>
    <message>
        <location filename="../../toonzlib/preferences.cpp" line="100"/>
        <source>Retas Level Format</source>
        <translation>Formát úrovně RETAS</translation>
    </message>
    <message>
        <location filename="../../toonzlib/preferences.cpp" line="106"/>
        <source>Adobe Photoshop</source>
        <translation>Adobe Photoshop</translation>
    </message>
    <message>
        <location filename="../../toonzlib/preferences.cpp" line="203"/>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="86"/>
        <source>No restrictions for uncompressed avi video</source>
        <translation>Žádná omezení pro nezabalený obrazový záznam AVI</translation>
    </message>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="93"/>
        <source>It is not possible to communicate with the codec.
 Probably the codec cannot work correctly.</source>
        <translation>Není možné komunikovat s kodekem.
Pravděpodobně kodek nemůže pracovat řádně.</translation>
    </message>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="125"/>
        <source>video width must be a multiple of %1</source>
        <translation>Šířka obrazu musí být násobkem %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="139"/>
        <source>video length must be a multiple of %1</source>
        <translation>Délka obrazu musí být násobkem %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="145"/>
        <source>No restrictions for this codec</source>
        <translation>Žádná omezení pro tento kodek</translation>
    </message>
    <message>
        <location filename="../../toonzlib/avicodecrestrictions.cpp" line="147"/>
        <source>Resolution restrictions:</source>
        <translation>Omezení pro rozlišení:</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="85"/>
        <source>New Camera  %1</source>
        <translation>Nová kamera %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="140"/>
        <source>New Pegbar  %1</source>
        <translation>Nový pruh na kolíky %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="187"/>
        <source>Set Active Camera  %1 &gt; %2</source>
        <translation>Nastavit činnou kameru %1 &gt; %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="245"/>
        <source>Remove Spline  %1</source>
        <translation>Odstranit křivku (spline) %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="291"/>
        <source>New Motion Path  %1</source>
        <translation>Nová cesta pohybu %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="334"/>
        <source>Link Motion Path  %1 &gt; %2</source>
        <translation>Spojit cestu pohybu %1 &gt; %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="460"/>
        <source>Remove Object  %1</source>
        <translation>Odstranit předmět %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tstageobjectcmd.cpp" line="546"/>
        <source>Remove Column  </source>
        <translation>Odstranit sloupec  </translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="47"/>
        <source>Failed to save palette.</source>
        <translation>Nepodařilo se uložit paletu.</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="85"/>
        <source>Load into Current Palette  &gt; %1</source>
        <translation>Nahrát do nynější palety &gt; %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="126"/>
        <source>Replace with Current Palette  &gt; %1</source>
        <translation>Nahradit nynější paletou &gt; %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="152"/>
        <source>Delete Studio Palette  : %1</source>
        <translation>Smazat studiovou paletu: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="178"/>
        <source>Create Studio Palette  : %1</source>
        <translation>Vytvořit studiovou paletu: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="223"/>
        <source>Delete Studio Palette Folder  : %1</source>
        <translation>Smazat složku se studiovou paletou: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="247"/>
        <source>Create Studio Palette Folder  : %1</source>
        <translation>Vytvořit složku se studiovou paletou: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="267"/>
        <source>Can&apos;t undo rename palette</source>
        <translation>Přejmenování palety nelze vrátit zpět</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="268"/>
        <source>Can&apos;t undo move palette</source>
        <translation>Přesunutí palety nelze vrátit zpět</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="280"/>
        <source>Can&apos;t redo rename palette</source>
        <translation>Nelze zopakovat přejmenování palety</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="281"/>
        <source>Can&apos;t redo move palette</source>
        <translation>Nelze zopakovat přesunutí palety</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="294"/>
        <source>Rename Studio Palette : %1 &gt; %2</source>
        <translation>Přejmenovat studiovou paletu: %1 &gt; %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/studiopalettecmd.cpp" line="298"/>
        <source>Move Studio Palette Folder  : %1 : %2 &gt; %3</source>
        <translation>Přesunout složku se studiovou paletou: %1 : %2 &gt; %3</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="251"/>
        <source>Arrange Styles  in Palette %1</source>
        <translation>Uspořádat styly v paletě: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="322"/>
        <source>Create Style#%1  in Palette %2</source>
        <translation>Vytvořit styl #%1 v paletě %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="453"/>
        <source>Add Style  to Palette %1</source>
        <translation>Přidat styl do palety %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="671"/>
        <source>Add Page %1 to Palette %2</source>
        <translation>Přidat stranu %1 do palety %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="736"/>
        <source>Delete Page %1 from Palette %2</source>
        <translation>Smazat stranu %1 z palety %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="791"/>
        <source>Load Color Model %1  to Palette %2</source>
        <translation>Nahrát barevný model %1 do palety %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="889"/>
        <source>color model</source>
        <translation>Barevný model</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="1057"/>
        <source>Move Page</source>
        <translation>Přesunout stranu</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="1108"/>
        <source>Rename Page  %1 &gt; %2</source>
        <translation>Přejmenovat stranu %1 &gt; %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="1172"/>
        <source>Rename Style#%1 in Palette%2  : %3 &gt; %4</source>
        <translation>Přejmenovat styl #%1 v paletě %2 : %3 &gt; %4</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="1237"/>
        <source>Set Picked Position of Style#%1 in Palette%2 : %3,%4</source>
        <translation>Nastavit zvolenou polohu stylu #%1 v paletě %2 : %3,%4</translation>
    </message>
    <message>
        <location filename="../../toonzlib/palettecmd.cpp" line="1316"/>
        <source>Update Colors by Using Picked Positions in Palette %1</source>
        <translation>Obnovit barvy použitím vybraných poloh v paletě %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="905"/>
        <source>Add Fx  : </source>
        <translation>Přidat efekt: </translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="906"/>
        <source>Insert Fx  : </source>
        <translation>Vložit efekt: </translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1068"/>
        <location filename="../../toonzlib/fxcommand.cpp" line="1071"/>
        <source>Create Linked Fx  : %1</source>
        <translation>Vytvořit propojený efekt: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1293"/>
        <source>Replace Fx  : </source>
        <translation>Nahradit efekt: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1359"/>
        <source>Unlink Fx  : %1 - - %2</source>
        <translation>Zrušit propojení efektu: %1 - - %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1400"/>
        <source>Make Macro Fx  : %1</source>
        <translation>Vytvořit makro efekt: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1543"/>
        <source>Explode Macro Fx  : %1</source>
        <translation>Rozbalit makro efekt: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1606"/>
        <source>Create Output Fx</source>
        <translation>Vytvořit výstupní efekt</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1697"/>
        <source>Connect to Xsheet  : </source>
        <translation>Spojit s Xsheet: </translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="1757"/>
        <source>Disconnect from Xsheet  : </source>
        <translation>Odpojit od Xsheet: </translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="2030"/>
        <source>Delete Link</source>
        <translation>Smazat spojení</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="2317"/>
        <source>Delete Fx Node : %1</source>
        <translation>Smazat uzel efektu: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="2740"/>
        <source>Paste Fx  :  </source>
        <translation>Vložit efekt:  </translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3109"/>
        <source>Disconnect Fx</source>
        <translation>Odpojit od efekt</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3361"/>
        <source>Connect Fx : %1 - %2</source>
        <translation>Spojit efekt: %1 - %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3543"/>
        <source>Rename Fx : %1 &gt; %2</source>
        <translation>Přejmenovat efekt: %1 - %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3595"/>
        <source>Group Fx</source>
        <translation>Seskupit efekt</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3699"/>
        <source>Ungroup Fx</source>
        <translation>Zrušit seskupení efektu</translation>
    </message>
    <message>
        <location filename="../../toonzlib/fxcommand.cpp" line="3801"/>
        <source>Rename Group  : %1 &gt; %2</source>
        <translation>Přejmenovat skupinu: %1 &gt; %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/doubleparamcmd.cpp" line="73"/>
        <source>Set Keyframe</source>
        <translation>Nastavit klíčový snímek</translation>
    </message>
    <message>
        <location filename="../../toonzlib/doubleparamcmd.cpp" line="816"/>
        <source>Remove Keyframe</source>
        <translation>Odstranit klíčový snímek</translation>
    </message>
    <message>
        <location filename="../../toonzlib/doubleparamcmd.cpp" line="856"/>
        <source>Cycle</source>
        <translation>Koloběh</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tpalettehandle.cpp" line="40"/>
        <source>Toggle Autopaint Option  Palette : %1  Style#%2</source>
        <translation>Přepnout volbu pro automatické malování  Paleta: %1  Styl #%2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="689"/>
        <location filename="../../toonzlib/txshcolumn.cpp" line="717"/>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="691"/>
        <location filename="../../toonzlib/sceneproperties.cpp" line="30"/>
        <source>Red</source>
        <translation>Červená</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="693"/>
        <location filename="../../toonzlib/sceneproperties.cpp" line="34"/>
        <source>Green</source>
        <translation>Zelená</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="695"/>
        <location filename="../../toonzlib/sceneproperties.cpp" line="36"/>
        <source>Blue</source>
        <translation>Modrá</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="697"/>
        <source>DarkYellow</source>
        <translation>Tmavá žlutá</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="699"/>
        <source>DarkCyan</source>
        <translation>Tmavá modrozelená</translation>
    </message>
    <message>
        <location filename="../../toonzlib/txshcolumn.cpp" line="701"/>
        <source>DarkMagenta</source>
        <translation>Tmavá červenorudá</translation>
    </message>
    <message>
        <location filename="../../toonzlib/tcleanupper.cpp" line="583"/>
        <source>The autocentering failed on the current drawing.</source>
        <translation>Automatické vystředění při nynější kresbě selhalo.</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="160"/>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="197"/>
        <source>Move</source>
        <translation>Přesunout</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="164"/>
        <source>Edit Rotation</source>
        <translation>Upravit otočení</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="167"/>
        <source>Move X</source>
        <translation>Posunout V/Z</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="170"/>
        <source>Move Y</source>
        <translation>Posunout S/J</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="173"/>
        <source>Move Z</source>
        <translation>Posunout Z</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="176"/>
        <source>Edit Stack Order</source>
        <translation>Upravit pořadí zásobníku</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="179"/>
        <source>Edit Scale W</source>
        <translation>Změnit velikost šířky</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="182"/>
        <source>Edit Scale H</source>
        <translation>Změnit velikost výšky</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="185"/>
        <source>Edit Scale</source>
        <translation>Upravit měřítko</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="188"/>
        <source>Edit PosPath</source>
        <translation>Upravit cestu polohy</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="191"/>
        <source>Edit Shear X</source>
        <translation>Upravit střih X</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="194"/>
        <source>Edit Shear Y</source>
        <translation>Upravit střih Y</translation>
    </message>
    <message>
        <location filename="../../toonzlib/stageobjectutil.cpp" line="202"/>
        <source>%1  %2  Frame : %3</source>
        <translation>%1  %2  Snímek: %3</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_renderer.cpp" line="29"/>
        <source>First argument must be a scene : %1</source>
        <translation>První argument musí být záběr: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_renderer.cpp" line="32"/>
        <source>Can&apos;t render empty scene</source>
        <translation>Nelze zpracovat prázdný záběr</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="41"/>
        <location filename="../../toonzlib/scriptbinding_centerline_vectorizer.cpp" line="43"/>
        <source>Vectorization failed</source>
        <translation>Vektorizace selhala</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="235"/>
        <source>Argument &apos;%1&apos; does not look like a FrameId</source>
        <translation>Argument &apos;%1&apos; nevypadá jako ID snímku</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="205"/>
        <source>Bad argument (%1): should be an Image (not empty)</source>
        <translation>Špatný argument (%1): měl by to být obrázek (ne prázdný)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_files.cpp" line="142"/>
        <source>Argument doesn&apos;t look like a file path : %1</source>
        <translation>Argument nevypadá jako souborová cesta: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding.cpp" line="75"/>
        <source>%1-%2</source>
        <translation>%1-%2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding.cpp" line="77"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding.cpp" line="79"/>
        <source>Expected %1 argument(s) in %2, got %3</source>
        <translation>Očekáván(o) %1 argument(ů) v %2, obdrženo %3</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding.cpp" line="95"/>
        <source>%1 is not a valid color (valid color names are &apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneresources.cpp" line="447"/>
        <source>Can&apos;t save</source>
        <translation>Nelze uložit</translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneresources.cpp" line="521"/>
        <source>and %1 more item(s).</source>
        <translation>a %1 další položku(y).</translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneresources.cpp" line="524"/>
        <source>Failed to save the following resources:
</source>
        <translation>Nepodařilo se uložit následující zdroje:
</translation>
    </message>
    <message>
        <location filename="../../toonzlib/orientation.cpp" line="81"/>
        <source>Xsheet</source>
        <translation>Xsheet</translation>
    </message>
    <message>
        <location filename="../../toonzlib/orientation.cpp" line="148"/>
        <source>Timeline</source>
        <translation>Časová osa</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="93"/>
        <source>Brightness</source>
        <translation>Jas</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="95"/>
        <source>Contrast</source>
        <translation>Kontrast</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="228"/>
        <source>HRange</source>
        <translation>Vodorovný rozsah</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="229"/>
        <source>Line Width</source>
        <translation>Tloušťka čáry</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="312"/>
        <source>ColorThres</source>
        <translation>Prahová hodnota barvy</translation>
    </message>
    <message>
        <location filename="../../toonzlib/cleanupcolorstyles.cpp" line="314"/>
        <source>WhiteThres</source>
        <translation>Prahová hodnota bílé</translation>
    </message>
    <message>
        <location filename="../../include/toonz/stageobjectutil.h" line="133"/>
        <source>Set Keyframe   %1 at frame %2</source>
        <translation>Nastavit klíčový snímek: %1 snímek %2</translation>
    </message>
    <message>
        <location filename="../../include/toonz/stageobjectutil.h" line="177"/>
        <source>Remove Keyframe   %1 at frame %2</source>
        <translation>Odstranit klíčový snímek: %1 snímek %2</translation>
    </message>
    <message>
        <location filename="../../include/toonz/stageobjectutil.h" line="212"/>
        <source>Move Center   %1  Frame %2</source>
        <translation>Přesunout střed   %1 snímek %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="31"/>
        <source>Orange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="32"/>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="33"/>
        <source>Light Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="35"/>
        <source>Light Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="37"/>
        <source>Dark Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="38"/>
        <source>Purple</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="39"/>
        <source>Pink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="40"/>
        <source>Dark Pink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../toonzlib/sceneproperties.cpp" line="41"/>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TScriptBinding::CenterlineVectorizer</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_centerline_vectorizer.cpp" line="69"/>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>Nelze vektorizovat úroveň %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_centerline_vectorizer.cpp" line="72"/>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>Nelze vektorizovat úroveň bez snímků</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_centerline_vectorizer.cpp" line="77"/>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>Nelze vektorizovat obrázek %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_centerline_vectorizer.cpp" line="83"/>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>Špatný argument (%1): měl by to být obrázek nebo úroveň</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::FilePath</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_files.cpp" line="29"/>
        <source>&quot;%1&quot;</source>
        <translation>&quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_files.cpp" line="107"/>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation>nemůže zřetězit absolutní cestu: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_files.cpp" line="115"/>
        <source>%1 is not a directory</source>
        <translation>%1 není adresář</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_files.cpp" line="129"/>
        <source>can&apos;t read directory %1</source>
        <translation>Nelze přečíst adresář %1</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Image</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="102"/>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Soubor %1 neexistuje</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="126"/>
        <source>Loaded first frame of %1</source>
        <translation>Nahrán první snímek z %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="144"/>
        <source>Unexpected error while reading image</source>
        <translation>Neočekávaná chyba při nahrávání obrázku</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="171"/>
        <source>Unrecognized file type :</source>
        <translation>Nerozpoznaný typ souboru:</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="175"/>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation>Nelze uložit %1 obrázek do tohoto typu souboru: %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image.cpp" line="196"/>
        <source>Unexpected error while writing image</source>
        <translation>Neočekávaná chyba při zapisování obrázku</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ImageBuilder</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="101"/>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation>Špatný argument (%1): má to být rastr nebo ToonzRaster</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="138"/>
        <source>ImageBuilder(%1 image)</source>
        <translation>ImageBuilder (%1 obrázek)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="265"/>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="285"/>
        <source>%1 : %2</source>
        <translation>%1: %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="278"/>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation>Špatný argument (%1): má to být proměna</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Level</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="67"/>
        <source>%1 frames</source>
        <translation>%1 snímků</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="122"/>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation>Špatný argument (%1): má to být souborová cesta nebo řetězec</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="130"/>
        <source>Exception loading level (%1)</source>
        <translation>Výjimka při nahrávání úrovně (%1)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="151"/>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Soubor %1 neexistuje</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="161"/>
        <source>File %1 is unsupported</source>
        <translation>Soubor %1 není podporován</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="170"/>
        <source>Exception reading %1</source>
        <translation>Výjimka při čtení %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="176"/>
        <source>Can&apos;t save an empty level</source>
        <translation>Nelze uložit prázdnou úroveň</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="196"/>
        <source>Unrecognized file type :</source>
        <translation>Nerozpoznaný typ souboru:</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="200"/>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation>Nelze uložit %1 úroveň do tohoto typu souboru: %2</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="209"/>
        <source>Exception writing %1</source>
        <translation>Výjimka při zápisu %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="268"/>
        <source>frame index (%1) must be a number</source>
        <translation>Číslo snímku (%1) musí být číslo</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="272"/>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation>Číslo snímku (%1) je mimo rozsah (0-%2)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="295"/>
        <source>second argument (%1) is not an image</source>
        <translation>druhýý argument (%1) není obrázkem</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="308"/>
        <source>can not insert a %1 image into a level</source>
        <translation>nelze vložit %1 obrázek do úrovně</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_level.cpp" line="329"/>
        <source>can not insert a %1 image to a %2 level</source>
        <translation>nelze vložit %1 obrázek do %2 úrovně</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::OutlineVectorizer</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="62"/>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>Nelze vektorizovat úroveň %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="65"/>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>Nelze vektorizovat úroveň bez snímků</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="70"/>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>Nelze vektorizovat obrázek %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="76"/>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>Špatný argument (%1): měl by to být obrázek nebo úroveň</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_outline_vectorizer.cpp" line="175"/>
        <source>Invalid color : </source>
        <translation>Neplatná barva: </translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Rasterizer</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_rasterizer.cpp" line="77"/>
        <source>Expected a vector image: %1</source>
        <translation>Očekáván vektorový obrázek: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_rasterizer.cpp" line="82"/>
        <source>Expected a vector level: %1</source>
        <translation>Očekávána vektorová úroveň: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_rasterizer.cpp" line="87"/>
        <source>Argument must be a vector level or image : </source>
        <translation>Argument musí být vektorová úroveň nebo obrázek: </translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_rasterizer.cpp" line="90"/>
        <source>%1 has no palette</source>
        <translation>%1 nemá žádnou paletu</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Scene</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="51"/>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Soubor %1 neexistuje</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="57"/>
        <source>Exception reading %1</source>
        <translation>Výjimka při čtení %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="72"/>
        <source>Exception writing %1</source>
        <translation>Výjimka při zápisu %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="113"/>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation>Špatný argument (%1): musí to být vektor, rastr nebo ToonzRaster</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="118"/>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="129"/>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation>Nelze přidat úroveň: název (%1) se již používá</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="136"/>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation>Nelze nahrát tento druh souboru jako úroveň: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="141"/>
        <source>Could not load level %1</source>
        <translation>Nepodařilo se nahrát úroveň %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="160"/>
        <source>Level is not included in the scene : %1</source>
        <translation>Úroveň není zahrnuta v záběru: %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="166"/>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation>%1: Očekávána instance úrovně nebo název úrovně</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_scene.cpp" line="171"/>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation>Úroveň &apos;%1&apos; není zahrnuta v záběru</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ToonzRasterConverter</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_toonz_raster_converter.cpp" line="34"/>
        <source>Can&apos;t convert a %1 level</source>
        <translation>Nelze převést úroveň %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_toonz_raster_converter.cpp" line="36"/>
        <source>Can&apos;t convert a level with no frames</source>
        <translation>Nelze převést úroveň bez snímků</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_toonz_raster_converter.cpp" line="40"/>
        <source>Can&apos;t convert a %1 image</source>
        <translation>Nelze převést obrázek %1</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_toonz_raster_converter.cpp" line="43"/>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation>Špatný argument (%1): má to být rastrová úroveň nebo rastrový obrázek</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Transform</name>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="23"/>
        <source>Identity</source>
        <translation>Matice totožnosti</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="25"/>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="30"/>
        <source>Translation(%1,%2)</source>
        <translation>Překlad (%1,%2)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="35"/>
        <source>Rotation(%1)</source>
        <translation>Otočení (%1)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="43"/>
        <source>Scale(%1%)</source>
        <translation>Měřítko (%1%)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="45"/>
        <source>Scale(%1%, %2%)</source>
        <translation>Měřítko (%1%, %2%)</translation>
    </message>
    <message>
        <location filename="../../toonzlib/scriptbinding_image_builder.cpp" line="53"/>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation>Proměna (%1, %2, %3;  %4, %5, %6)</translation>
    </message>
</context>
</TS>
